@@ -354,7 +354,7 @@ int qh_rboxpoints(qhT *qh, char* rbox_command) {
     }
   }else if (israndom) {
     seed= (int)time(&timedata);
-    sprintf(seedbuf, " t%d", seed);  /* appends an extra t, not worth removing */
+    snprintf(seedbuf, 22, " t%d", seed);  /* appends an extra t, not worth removing */
     strncat(command, seedbuf, sizeof(command)-strlen(command)-1);
     t= strstr(command, " t ");
     if (t)
